# pyclock
## An open-source, python library to viewing dates and times

### How to install
```
pip install pydatetime-v1.1.1
```
### How to get the current day and time
```
from pydatetime.pydatetime import *

x = current()
print(x)
```

v1.1.1
TSMSD Knabberpause Software 2022



